@@ -200,17 +200,12 @@ def run(actions, debug):
 
         for action in actions:
             click.echo("performing " + str(action.vac_command))
-            vacbot.request_all_statuses()
+            #vacbot.request_all_statuses()
             vacbot.refresh_liveMap()
             _LOGGER.debug("Vacuum Status: {}".format(vacbot.vacuum_status))
             _LOGGER.debug("Fan Speed: {}".format(vacbot.fan_speed))
             _LOGGER.debug("Image Url: {}".format(vacbot.last_clean_image))
             _LOGGER.debug("Live Map: {}".format(vacbot.live_map))
-            
-        for v in vacbot.rooms:
-            _LOGGER.debug(v)
-
-    
 
     click.echo("done")
 
