@@ -109,6 +109,8 @@ class Map:
             im = Image.new("RGBA", (1000, 1000))
             draw = ImageDraw.Draw(im)
             roomnr = 0
+
+            _LOGGER.debug("GetBase64Map draw_rooms")
             #Draw Rooms
             for room in self.rooms:
                 coordsXY = room['values'].split(';')
@@ -141,6 +143,7 @@ class Map:
                 draw.line(listcord,fill=(0,0,0,0),width=1)
                 roomnr = roomnr +1
 
+            _LOGGER.debug("GetBase64Map draw_map")
             #Draw MAP
             imageX = 0
             imageY = 0
@@ -166,26 +169,32 @@ class Map:
 
             del draw
 
+            _LOGGER.debug("GetBase64Map resize")
             # Resize * resizeFactor
             im = im.resize((im.size[0]*resizeFactor, im.size[1]*resizeFactor), Image.NEAREST)
 
             if self.draw_charger:
+                _LOGGER.debug("GetBase64Map draw robot")
                 #Draw Current Deebot Position
                 robot_icon = Image.open("robot.png")
                 im.paste(robot_icon, (int(((self.robot_position['x']/pixelWidth)+offset)*resizeFactor), int(((self.robot_position['y']/pixelWidth)+offset)*resizeFactor)), robot_icon.convert('RGBA'))
 
             if self.draw_robot:
+                _LOGGER.debug("GetBase64Map draw charger")
                 #Draw charger
                 charger_icon = Image.open("charger.png")
                 im.paste(charger_icon, (int(((self.charger_position['x']/pixelWidth)+offset)*resizeFactor), int(((self.charger_position['y']/pixelWidth)+offset)*resizeFactor)), charger_icon.convert('RGBA'))
 
+            _LOGGER.debug("GetBase64Map flip")
             #Flip
             im = ImageOps.flip(im)
 
+            _LOGGER.debug("GetBase64Map crop")
             #Crop
             imageBox = im.getbbox()
             cropped=im.crop(imageBox)
 
+            _LOGGER.debug("GetBase64Map save")
             #save
             buffered = BytesIO()
 
